"""Core API for safecmd"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/01_core.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/01_core.ipynb 2
import shlex,subprocess,json,shutil
from fastcore.utils import *
